@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.118_07';
+our $VERSION = '0.118_08';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Apr  8 12:29:37 2019 GMT
+# on Sat Apr 13 15:20:01 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1727,7 +1727,7 @@ __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
 __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
-__PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
+__PACKAGE__->status( add => 25104, iridium => '-', 'Iridium 45', 'Tumbling' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
 __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
@@ -1783,9 +1783,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 2
+# Operational [+]: 1
 #       Spare [S]: 2
-#    Tumbling [-]: 32
+#    Tumbling [-]: 33
 #     Decayed [D]: 61
 
 1;
